pub fn sidebar_chrome() -> SidebarChromeExpand description
The sidebar state the user last settled on, or the expanded default when the shell is not initialized.
pub fn sidebar_chrome() -> SidebarChromeThe sidebar state the user last settled on, or the expanded default when the shell is not initialized.